@@ -11,10 +11,10 @@ more.
 Visit http://pypi.python.org/pypi/python_toolbox/ for more info.
 '''
 
-import python_toolbox.bootstrap
+import python_toolbox._bootstrap
 import python_toolbox.version_info
 import python_toolbox.monkeypatch_copy_reg
 
-__version_info__ = python_toolbox.version_info.VersionInfo(0, 3, 0)
-__version__ = '0.3'
+__version_info__ = python_toolbox.version_info.VersionInfo(0, 4, 0)
+__version__ = '0.4'
 
