@@ -5,6 +5,6 @@
 
 # todo: examine thread-safety
 
-from .cache import cache
+from .decorators import cache
 from .cached_type import CachedType
 from .cached_property import CachedProperty
\ No newline at end of file
