@@ -5,11 +5,13 @@
 
 import nose.tools
 
-from python_toolbox.infinity import infinity
 from python_toolbox import cute_iter_tools
 from python_toolbox.cute_iter_tools import shorten
 
 
+infinity = float('inf')
+
+
 def test():
     '''Test basic workings of `shorten`.'''
     my_range = [0, 1, 2, 3, 4]
